@@ -9,6 +9,7 @@ using Mono.Unix;
 namespace Tomboy
 {
 	public delegate void NoteRenameHandler (Note sender, string old_title);
+	public delegate void NoteSavedHandler (Note note);
 
 	// Contains all pure note data, like the note title and note text.
 	public class NoteData
@@ -148,50 +149,29 @@ namespace Tomboy
 		public NoteBuffer Buffer
 		{
 			get { return buffer; }
-			set
-			{
+			set {
 				buffer = value;
-
-				// Don't create Undo actions during load
-				buffer.Undoer.FreezeUndo ();
-
-				// Load the stored xml text
-				if (!TextInvalid ()) {
-					NoteBufferArchiver.Deserialize (buffer, 
-									buffer.StartIter, 
-									data.Text);
-				}
-				buffer.Modified = false;
-
-				Gtk.TextIter cursor;
-				if (data.CursorPosition != 0) {
-					// Move cursor to last-saved position
-					cursor = buffer.GetIterAtOffset (data.CursorPosition);
-				} else {
-					// Avoid title line
-					cursor = buffer.GetIterAtLine (2);
-				}
-				buffer.PlaceCursor (cursor);
-
-				// New events should create Undo actions
-				buffer.Undoer.ThawUndo ();
-
 				buffer.Changed += BufferChanged;
 				buffer.TagApplied += BufferTagApplied;
 				buffer.TagRemoved += BufferTagRemoved;
 
+				SynchronizeBuffer ();
+
 				InvalidateText ();
 			}
 		}
 
+		//Text is actually an Xml formatted string
 		public string Text
 		{
-			get
-			{
+			get {
 				SynchronizeText ();
 				return data.Text;
 			}
-			set { data.Text = value; }
+			set {
+				data.Text = value;
+				SynchronizeBuffer ();
+			}
 		}
 
 		// Custom Methods
@@ -213,6 +193,35 @@ namespace Tomboy
 			}
 		}
 
+		void SynchronizeBuffer ()
+		{
+			if (!TextInvalid () && buffer != null) {
+				// Don't create Undo actions during load
+				buffer.Undoer.FreezeUndo ();
+
+				buffer.Clear ();
+
+				// Load the stored xml text
+				NoteBufferArchiver.Deserialize (buffer, 
+								buffer.StartIter, 
+								data.Text);
+				buffer.Modified = false;
+
+				Gtk.TextIter cursor;
+				if (data.CursorPosition != 0) {
+					// Move cursor to last-saved position
+					cursor = buffer.GetIterAtOffset (data.CursorPosition);
+				} else {
+					// Avoid title line
+					cursor = buffer.GetIterAtLine (2);
+				}
+				buffer.PlaceCursor (cursor);
+
+				// New events should create Undo actions
+				buffer.Undoer.ThawUndo ();
+			}
+		}
+
 		// Callbacks
 
 		void BufferChanged (object sender, EventArgs args)
@@ -286,7 +295,6 @@ namespace Tomboy
 						       string filepath,
 						       NoteManager manager)
 		{
-			data.CreateDate = DateTime.MinValue;
 			data.ChangeDate = File.GetLastWriteTime (filepath);
 			return new Note (data, filepath, manager);
 		}
@@ -320,6 +328,9 @@ namespace Tomboy
 			Logger.Log ("Saving '{0}'...", data.Data.Title);
 
 			NoteArchiver.Write (filepath, data.GetDataSynchronized ());
+			
+			if (Saved != null)
+				Saved (this);
 		}
 
 		//
@@ -457,7 +468,12 @@ namespace Tomboy
 		public string XmlContent 
 		{
 			get { return data.Text; }
-			set { data.Text = value; }
+			set { 
+				if (buffer != null)
+					buffer.SetText (XmlDecoder.Decode (value));
+				else
+					data.Text = value; 
+			}
 		}
 
 		public string TextContent
@@ -470,6 +486,13 @@ namespace Tomboy
 				else 
 					return XmlDecoder.Decode (XmlContent);
 			}
+			set {
+				if (buffer != null)
+					buffer.SetText (value);
+				else
+					Logger.Log ("Setting text content for closed notes not supported");
+			}
+				
 		}
 
 		public NoteData Data
@@ -515,11 +538,17 @@ namespace Tomboy
 			}
 		}
 
+		public bool HasBuffer
+		{
+			get { return null != buffer; }
+		}
+
 		public NoteBuffer Buffer
 		{
 			get {
 				if (buffer == null) {
-					Logger.Log ("Creating Buffer for '{0}'...", data.Data.Title);
+					Logger.Log ("Creating Buffer for '{0}'...", 
+						    data.Data.Title);
 
 					buffer = new NoteBuffer (TagTable);
 					data.Buffer = buffer;
@@ -534,6 +563,11 @@ namespace Tomboy
 			}
 		}
 
+		public bool HasWindow
+		{
+			get { return null != window; }
+		}
+
 		public NoteWindow Window 
 		{
 			get {
@@ -543,7 +577,8 @@ namespace Tomboy
 					window.ConfigureEvent += WindowConfigureEvent;
 					
 					if (data.Data.HasExtent ())
-						window.SetDefaultSize (data.Data.Width, data.Data.Height);
+						window.SetDefaultSize (data.Data.Width, 
+								       data.Data.Height);
 
 					if (data.Data.HasPosition ())
 						window.Move (data.Data.X, data.Data.Y);
@@ -559,7 +594,7 @@ namespace Tomboy
 
 		public bool IsSpecial 
 		{
-			get { return data.Data.Title == Catalog.GetString ("Start Here"); }
+			get { return NoteManager.StartNoteUri == data.Data.Uri; }
 		}
 
 		public bool IsNew 
@@ -580,8 +615,40 @@ namespace Tomboy
 			get { return window != null; }
 		}
 
+		public bool IsPinned
+		{
+			get {
+				string pinned_uris = (string)
+					Preferences.Get (Preferences.MENU_PINNED_NOTES);
+				return pinned_uris.IndexOf (Uri) > -1;
+			}
+			set {
+				string new_pinned = "";
+				string old_pinned = (string)
+					Preferences.Get (Preferences.MENU_PINNED_NOTES);
+				bool pinned = old_pinned.IndexOf (Uri) > -1;
+
+				if (value == pinned) 
+					return;
+
+				if (value) {
+					new_pinned = Uri + " " + old_pinned;
+				} else {
+					string [] pinned_split = old_pinned.Split (' ', '\t', '\n');
+					foreach (string pin in pinned_split) {
+						if (pin != "" && pin != Uri) {
+							new_pinned += pin + " ";
+						}
+					}
+				}
+
+				Preferences.Set (Preferences.MENU_PINNED_NOTES, new_pinned);
+			}
+		}
+
 		public event EventHandler Opened;
 		public event NoteRenameHandler Renamed;
+		public event NoteSavedHandler Saved;
 	}
 
 	// Singleton - allow overriding the instance for easy sensing in
@@ -590,6 +657,8 @@ namespace Tomboy
 	public class NoteArchiver
 	{
 		public const string CURRENT_VERSION = "0.2";
+		
+		public const string DATE_TIME_FORMAT = "yyyy-MM-ddTHH:mm:ss.fffffffzzz";
 
 		static NoteArchiver instance = null;
 		static readonly object lock_ = new object();
@@ -649,11 +718,11 @@ namespace Tomboy
 						break;
 					case "last-change-date":
 						note.ChangeDate = 
-							XmlConvert.ToDateTime (xml.ReadString ());
+							XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "create-date":
 						note.CreateDate = 
-							XmlConvert.ToDateTime (xml.ReadString ());
+							XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
 					case "cursor-position":
 						note.CursorPosition = int.Parse (xml.ReadString ());
@@ -761,12 +830,14 @@ namespace Tomboy
 			xml.WriteEndElement ();
 
 			xml.WriteStartElement (null, "last-change-date", null);
-			xml.WriteString (XmlConvert.ToString (note.ChangeDate));
+			xml.WriteString (
+						XmlConvert.ToString (note.ChangeDate, DATE_TIME_FORMAT));
 			xml.WriteEndElement ();
 
 			if (note.CreateDate != DateTime.MinValue) {
 				xml.WriteStartElement (null, "create-date", null);
-				xml.WriteString (XmlConvert.ToString (note.CreateDate));
+				xml.WriteString (
+						XmlConvert.ToString (note.CreateDate, DATE_TIME_FORMAT));
 				xml.WriteEndElement ();
 			}
 
