@@ -15,6 +15,27 @@ namespace Tomboy
 		ArrayList notes;
 		PluginManager plugin_mgr;
 		TrieController trie_controller;
+		
+		static string start_note_uri = String.Empty;
+
+		static NoteManager ()
+		{
+			// Watch the START_NOTE_URI setting and update it so that the
+			// StartNoteUri property doesn't generate a call to
+			// Preferences.Get () each time it's accessed.
+			start_note_uri =
+				Preferences.Get (Preferences.START_NOTE_URI) as string;
+			Preferences.SettingChanged += OnSettingChanged;
+		}
+		
+		static void OnSettingChanged (object sender, GConf.NotifyEventArgs args)
+		{
+			switch (args.Key) {
+			case Preferences.START_NOTE_URI:
+				start_note_uri = args.Value as string;
+				break;
+			}
+		}
 
 		public NoteManager (string directory) : 
 			this (directory, Path.Combine (directory, "Backup")) 
@@ -36,8 +57,8 @@ namespace Tomboy
 			trie_controller = CreateTrieController ();
 
 			if (first_run) {
-				// First run. Create "Start Here" note.
-				CreateStartNote ();
+				// First run. Create "Start Here" notes.
+				CreateStartNotes ();
 			} else {
 				LoadNotes ();
 			}
@@ -49,10 +70,18 @@ namespace Tomboy
 		// methods.
 		protected virtual PluginManager CreatePluginManager ()
 		{
-			string tomboy_dir = 
-				Path.Combine (Environment.GetEnvironmentVariable ("HOME"), 
-					      ".tomboy");
-			string plugins_dir = Path.Combine (tomboy_dir, "Plugins");
+			// Allow developers to override the plugins path with an
+			// environment variable.
+			string plugins_dir =
+				Environment.GetEnvironmentVariable ("TOMBOY_PLUGINS_PATH");
+
+			if (plugins_dir == null) {
+				string tomboy_dir = 
+					Path.Combine (Environment.GetEnvironmentVariable ("HOME"), 
+						      ".tomboy");
+				plugins_dir = Path.Combine (tomboy_dir, "Plugins");
+			}
+
 			PluginManager.CreatePluginsDir (plugins_dir);
 
 			return new PluginManager (plugins_dir);
@@ -95,28 +124,68 @@ namespace Tomboy
 			if (NoteRenamed != null)
 				NoteRenamed (note, old_title);
 		}
-
-		protected virtual void CreateStartNote () 
+		
+		void OnNoteSave (Note note)
 		{
-			string content = 
-				string.Format ("<note-content>" +
-					       "{0}\n\n" +
-					       "<bold>{1}</bold>\n\n" +
-					       "{2}" +
-					       "</note-content>",
-					       Catalog.GetString ("Start Here"),
-					       Catalog.GetString ("Welcome to Tomboy!"),
-					       Catalog.GetString ("Use this page as a Start Page " +
-								  "for organizing your notes and " +
-								  "keeping unorganized ideas " +
-								  "around."));
+			if (NoteSaved != null)
+				NoteSaved (note);
+		}
+
+		protected virtual void CreateStartNotes () 
+		{
+			// FIXME: Delay the creation of the start notes so the panel/tray
+			// icon has enough time to appear so that Tomboy.TrayIconShowing
+			// is valid.  Then, we'll be able to instruct the user where to
+			// find the Tomboy icon.
+			//string icon_str = Tomboy.TrayIconShowing ?
+			//					Catalog.GetString ("System Tray Icon area") :
+			//					Catalog.GetString ("GNOME Panel");
+			string start_note_content = 
+				Catalog.GetString ("<note-content>" +
+						"Start Here\n\n" +
+						"<bold>Welcome to Tomboy!</bold>\n\n" +
+						"Use this \"Start Here\" note to begin organizing " +
+						"your ideas and thoughts.\n\n" +
+						"You can create new notes to hold your ideas by " +
+						"selecting the \"Create New Note\" item from the " +
+						"Tomboy Notes menu in your GNOME Panel. " +
+						"Your note will be saved automatically.\n\n" +
+						"Then organize the notes you create by linking " +
+						"related notes and ideas together!\n\n" +
+						"We've created a note called " +
+						"<link:internal>Using Links in Tomboy</link:internal>.  " +
+						"Notice how each time we type <link:internal>Using " +
+						"Links in Tomboy</link:internal> it automatically " +
+						"gets underlined?  Click on the link to open the note." +
+						"</note-content>");
+
+			string links_note_content =
+				Catalog.GetString ("<note-content>" +
+						"Using Links in Tomboy\n\n" +
+						"Notes in Tomboy can be linked together by " +
+						"highlighting text in the current note and clicking" +
+						" the <bold>Link</bold> button above in the toolbar.  " +
+						"Doing so will create a new note and also underline " +
+						"the note's title in the current note.\n\n" +
+						"Changing the title of a note will update links " +
+						"present in other notes.  This prevents broken links " +
+						"from occurring when a note is renamed.\n\n" +
+						"Also, if you type the name of another note in your " +
+						"current note, it will automatically be linked for you." +
+						"</note-content>");
 
 			try {
-				Note start_note = Create (Catalog.GetString ("Start Here"), 
-							  content);
+				Note start_note = Create (Catalog.GetString ("Start Here"),
+								start_note_content);
 				start_note.Save ();
+				Preferences.Set (Preferences.START_NOTE_URI, start_note.Uri);
+
+				Note links_note = Create (Catalog.GetString ("Using Links in Tomboy"),
+								links_note_content);
+				links_note.Save ();
+				
 				start_note.Window.Show ();
-			} catch (Exception e) {
+			} catch {
 				// Fail silently
 			}
 		}
@@ -130,6 +199,7 @@ namespace Tomboy
 					Note note = Note.Load (file_path, this);
 					if (note != null) {
 						note.Renamed += OnNoteRename;
+						note.Saved += OnNoteSave;
 						notes.Add (note);
 					}
 				} catch (System.Xml.XmlException e) {
@@ -149,6 +219,16 @@ namespace Tomboy
 			foreach (Note note in notesCopy) {
 				plugin_mgr.LoadPluginsForNote (note);
 			}
+			
+			// Make sure that a Start Note Uri is set in the preferences.  This
+			// has to be done here for long-time Tomboy users who won't go
+			// through the CreateStartNotes () process.
+			if (StartNoteUri == String.Empty) {
+				// Attempt to find an existing Start Here note
+				Note start_note = Find (Catalog.GetString ("Start Here"));
+				if (start_note != null)
+					Preferences.Set (Preferences.START_NOTE_URI, start_note.Uri);
+			}
 		}
 
 		void OnExitingEvent (object sender, EventArgs args)
@@ -280,6 +360,7 @@ namespace Tomboy
 			Note new_note = Note.CreateNewNote (title, filename, this);
 			new_note.XmlContent = xml_content;
 			new_note.Renamed += OnNoteRename;
+			new_note.Saved += OnNoteSave;
 
 			notes.Add (new_note);
 
@@ -325,6 +406,11 @@ namespace Tomboy
 								 note_a.ChangeDate);
 			}
 		}
+		
+		public static string StartNoteUri
+		{
+			get { return start_note_uri; }
+		}
 
 		public ArrayList Notes 
 		{
@@ -353,6 +439,7 @@ namespace Tomboy
 		public event NotesChangedHandler NoteDeleted;
 		public event NotesChangedHandler NoteAdded;
 		public event NoteRenameHandler NoteRenamed;
+		public event NoteSavedHandler NoteSaved;
 	}
 
 	public class TrieController
