@@ -146,6 +146,7 @@ class EvoUtils
 			case "imapp":
 			case "groupwise":
 			case "nntp":
+			case "exchange":
 				match = (uri.Authority == source_uri.Authority) &&
 					(uri.UserInfo == source_uri.UserInfo);
 				break;
@@ -271,6 +272,12 @@ public class EmailLink : DynamicNoteTag
 	}
 }
 
+[PluginInfo(
+	"Evolution Plugin", Defines.VERSION,
+	"Alex Gravely <alex@beatniksoftware.com>",
+	"Allows you to drag an email from Evolution into a tomboy note.  The " +
+	"message subject is added as a link in the note."
+	)]
 public class EvolutionPlugin : NotePlugin
 {
 	// Used in the two-phase evolution drop handling.
@@ -298,7 +305,8 @@ public class EvolutionPlugin : NotePlugin
 
 	protected override void Shutdown ()
 	{
-		TargetList.Remove (Gdk.Atom.Intern ("x-uid-list", false));
+		if (HasWindow)
+			TargetList.Remove (Gdk.Atom.Intern ("x-uid-list", false));
 	}
 
 	protected override void OnNoteOpened () 
