@@ -2,7 +2,7 @@
 using System;
 using System.Collections;
 using System.Runtime.InteropServices;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Tomboy
 {
@@ -103,8 +103,8 @@ namespace Tomboy
 							       this);
 				bindings.Add (binding);
 			} catch (Exception e) {
-				Console.WriteLine ("Error Adding global keybinding:");
-				Console.WriteLine (e);
+				Logger.Log ("Error Adding global keybinding:");
+				Logger.Log (e.ToString ());
 			}
 		}
 
@@ -114,8 +114,8 @@ namespace Tomboy
 				bindings.Clear ();
 				base.UnbindAll ();
 			} catch (Exception e) {
-				Console.WriteLine ("Error Removing global keybinding:");
-				Console.WriteLine (e);
+				Logger.Log ("Error Removing global keybinding:");
+				Logger.Log (e.ToString ());
 			}
 		}
 
@@ -138,8 +138,8 @@ namespace Tomboy
 
 				try {
 					key_sequence = (string) parent.client.Get (gconf_path);
-				} catch (Exception e) {
-					Console.WriteLine ("GConf key '{0}' does not exist, using default.", 
+				} catch {
+					Logger.Log ("GConf key '{0}' does not exist, using default.", 
 							   gconf_path);
 				}
 
@@ -153,7 +153,7 @@ namespace Tomboy
 			void BindingChanged (object sender, GConf.NotifyEventArgs args)
 			{
 				if (args.Key == gconf_path) {
-					Console.WriteLine ("Binding for '{0}' changed to '{1}'!",
+					Logger.Log ("Binding for '{0}' changed to '{1}'!",
 							   gconf_path,
 							   args.Value);
 
@@ -171,7 +171,7 @@ namespace Tomboy
 				    key_sequence == "disabled")
 					return;
 
-				Console.WriteLine ("Binding key '{0}' for '{1}'",
+				Logger.Log ("Binding key '{0}' for '{1}'",
 						   key_sequence,
 						   gconf_path);
 
@@ -183,7 +183,7 @@ namespace Tomboy
 				if (key_sequence == null)
 					return;
 
-				Console.WriteLine ("Unbinding key '{0}' for '{1}'",
+				Logger.Log ("Unbinding key '{0}' for '{1}'",
 						   key_sequence,
 						   gconf_path);
 
@@ -218,7 +218,7 @@ namespace Tomboy
 
 		void EnableDisable (bool enable)
 		{
-			Console.WriteLine ("EnableDisable Called: enabling... {0}", enable);
+			Logger.Log ("EnableDisable Called: enabling... {0}", enable);
 			if (enable) {
 				BindPreference (Preferences.KEYBINDING_SHOW_NOTE_MENU,
 						new EventHandler (KeyShowMenu));
@@ -256,7 +256,7 @@ namespace Tomboy
 
 		void KeyOpenStartHere (object sender, EventArgs args)
 		{
-			Note note = manager.Find (Catalog.GetString ("Start Here"));
+			Note note = manager.FindByUri (NoteManager.StartNoteUri);
 			if (note != null)
 				note.Window.Present ();
 		}
@@ -266,20 +266,24 @@ namespace Tomboy
 			try {
 				Note new_note = manager.Create ();
 				new_note.Window.Show ();
-			} catch (Exception e) {
+			} catch {
 				// Fail silently.
 			}
 		}
 
 		void KeyOpenSearch (object sender, EventArgs args)
 		{
+			/* Find dialog is deprecated in favor of searcable ToC */
+			/*
 			NoteFindDialog find_dialog = NoteFindDialog.GetInstance (manager);
 			find_dialog.Present ();
+			*/
+			KeyOpenRecentChanges (sender, args);
 		}
 
 		void KeyOpenRecentChanges (object sender, EventArgs args)
 		{
-			Gtk.Window recent = new NoteRecentChanges (manager);
+			Gtk.Window recent = NoteRecentChanges.GetInstance (manager);
 			recent.Show ();
 		}
 	}
